@@ -11,7 +11,7 @@ permTest<-function(x,method="minimum",K)
   if (is.na(type.method))
     stop ("\n method should be 'minimum' or 'rtp'")
 
-  w<-options(warn=-1)
+  # w <- options(warn=-1)
 
   if (type.method==1)
    {  
@@ -49,7 +49,7 @@ permTest<-function(x,method="minimum",K)
      ans<-list(rtp=stat,sig=sig,nSNPs=c(valid.SNPs,discarded.SNPs),K=K)
    }
 
-  options(w)
+  # options(w)
   
   attr(ans,"method")<-type.method
   class(ans)<-"permTest"
